pub trait ComputeSystemMessage {
// Required method
fn system_message() -> String;
}Expand description
Two new traits that users must implement:
ComputeSystemMessageto provide a static or dynamic system message.ComputeLanguageModelCoreQueryto build requests for each seed item.
These traits are now required components of the overall workflow.
We define them in the same batch_mode_batch_workflow (or relevant) crate
so that the derive macro can reference them.
Required Methods
Sourcefn system_message() -> String
fn system_message() -> String
Returns the system message to be applied to all requests.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".