LanguageModelBatchWorkflowGatherResults

Trait LanguageModelBatchWorkflowGatherResults 

pub trait LanguageModelBatchWorkflowGatherResults {
    type Error;
    type Seed: HasAssociatedOutputName + Clone + Named;
    type Output: LoadFromFile<Error = SaveLoadError>;

    // Required method
    fn gather_results<'life0, 'life1, 'async_trait>(
        &'life0 self,
        seeds: &'life1 [Self::Seed],
    ) -> Pin<Box<dyn Future<Output = Result<Vec<(Self::Seed, Self::Output)>, Self::Error>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
This new trait is used to gather the final AI expansions from disk, matching each seed item to its parsed output JSON.

Required Associated Types

Required Methods

fn gather_results<'life0, 'life1, 'async_trait>( &'life0 self, seeds: &'life1 [Self::Seed], ) -> Pin<Box<dyn Future<Output = Result<Vec<(Self::Seed, Self::Output)>, Self::Error>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Gathers AI-generated JSON outputs for the given seeds in the same order, returning (Seed, Output) pairs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors